==> fediz-cxf-1.2.3-sources.jar: org/apache/cxf/fediz/cxf/plugin/FedizSecurityContext.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.fediz.cxf.plugin;

import java.security.Principal;
import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import org.apache.cxf.common.security.SimplePrincipal;
import org.apache.cxf.security.SecurityContext;

public class FedizSecurityContext implements SecurityContext {
    
    private Principal principal;
    private Set<Principal> roles;

    public FedizSecurityContext(Principal principal,
                                Collection<String> roles) {
        this.principal = principal;
        this.roles = new HashSet<Principal>();
        if (roles != null) {
            for (String role : roles) {
                this.roles.add(new SimplePrincipal(role));
            }
        }
    }
    
    @Override
    public Principal getUserPrincipal() {
        return principal;
    }

    @Override
    public boolean isUserInRole(String role) {
        for (Principal p : roles) {
            if (p.getName().equals(role)) {
                return true;
            }
        }
        
        return false;
    }

}

==> fediz-cxf-1.3.2-sources.jar: org/apache/cxf/fediz/cxf/plugin/FedizSecurityContext.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.fediz.cxf.plugin;

import java.security.Principal;
import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import org.apache.cxf.common.security.SimplePrincipal;
import org.apache.cxf.security.SecurityContext;

public class FedizSecurityContext implements SecurityContext {
    
    private Principal principal;
    private Set<Principal> roles;

    public FedizSecurityContext(Principal principal,
                                Collection<String> roles) {
        this.principal = principal;
        this.roles = new HashSet<>();
        if (roles != null) {
            for (String role : roles) {
                this.roles.add(new SimplePrincipal(role));
            }
        }
    }
    
    @Override
    public Principal getUserPrincipal() {
        return principal;
    }

    @Override
    public boolean isUserInRole(String role) {
        for (Principal p : roles) {
            if (p.getName().equals(role)) {
                return true;
            }
        }
        
        return false;
    }

}
